# Documentation for `FRegressionFilterPValue`
::: photonai.modelwrapper.feature_selection.FRegressionFilterPValue
    selection:
      members:
        - __init__
        - fit
        - transform
        - inverse_transform
